@@ -282,7 +282,7 @@ void SettingsBase::initMenuList(MenuItem *parent)
             ? parent->service()->property(QStringLiteral("X-KDE-System-Settings-Category-Module")).toString()
             : QString();
 
-        if (parentCategoryKcm == entry->library()) {
+        if (!parentCategoryKcm.isEmpty() && parentCategoryKcm == entry->library()) {
             parent->setItem(KCModuleInfo(entry));
             removeList.append(modules.at(i));
         } else if (!parent->category().isEmpty() && (category == parent->category() || category2 == parent->category())) {
